
# THIS FILE IS GENERATED FROM PYART SETUP.PY
short_version = '0.6.2'
version = '0.6.2'
full_version = '0.6.2.dev+12352d5'
git_revision = '12352d5d06f9441ca9ac555f75f8d905e7e57d94'
release = False

if not release:
    version = full_version
